@@ -31,6 +31,14 @@ class NodeProfile:
     REMOTE = 41
     IMPULSE_PLUG = 42
     IMPULSE_RELAY = 43
+    WALL_MOTE = 44
+    WIFI_ONE_BUTTON_REMOTE = 45
+    WIFI_METERING_SWITCH = 46
+    WIFI_ON_OFF_METERING_SWITCH = 47
+    WIFI_ON_OFF_METERING_PLUG = 48
+    WIFI_ON_OFF_DIMMABLE_METERING_SWITCH = 49
+    WIFI_ON_OFF_SWITCH = 50
+    WIFI_ENERGY_METER = 51
     BRIGHTNESS_SENSOR = 1e3
     DIMMABLE_COLOR_LIGHT = 1001
     DIMMABLE_EXTENDED_COLOR_LIGHT = 1002
@@ -40,6 +48,8 @@ class NodeProfile:
     DIMMABLE_LIGHT_WITH_BRIGHTNESS_AND_PRESENCE_SENSOR = 1006
     DIMMABLE_LIGHT_WITH_PRESENCE_SENSOR = 1007
     DIMMABLE_RGBWLIGHT = 1008
+    WIFI_DIMMABLE_RGBWLIGHT = 1009
+    WIFI_DIMMABLE_LIGHT = 1010
     OPEN_CLOSE_SENSOR = 2e3
     WINDOW_HANDLE = 2001
     SHUTTER_POSITION_SWITCH = 2002
@@ -56,6 +66,10 @@ class NodeProfile:
     GATE_OPERATOR = 2013
     INNER_DOOR_OPERATOR = 2014
     GARAGE_DOOR_IMPULSE_OPERATOR = 2015
+    ENTRANCE_DOOR = 2016
+    WINDOW_MOTOR_SWITCH = 2017
+    WIFI_OPEN_CLOSE_SENSOR = 2018
+    WIFI_ELECTRIC_MOTOR_METERING_SWITCH = 2019
     TEMPERATURE_AND_HUMIDITY_SENSOR = 3001
     CO2SENSOR = 3002
     ROOM_THERMOSTAT = 3003
@@ -82,6 +96,9 @@ class NodeProfile:
     HEATING_SYSTEM = 3028
     WARM_WATER_CIRCUIT = 3029
     HEATING_CIRCUIT = 3030
+    AIR_Quality_SENSOR = 3031
+    WIFI_ROOM_THERMOSTAT = 3032
+    WIFI_RADIATOR_THERMOSTAT = 3033
     MOTION_DETECTOR_WITH_TEMPERATURE_BRIGHTNESS_AND_HUMIDITY_SENSOR = 4010
     MOTION_DETECTOR = 4011
     SMOKE_DETECTOR = 4012
@@ -109,6 +126,10 @@ class NodeProfile:
     MAXIMUM_DETECTOR_WITH_TEMPERATURE_SENSOR = 4034
     PRESENCE_DETECTOR_WITH_TEMPERATURE_AND_BRIGHTNESS_SENSOR = 4035
     CODETECTOR = 4036
+    TRACKER = 4037
+    WIFI_FLOOD_DETECTOR = 4038
+    WIFI_MOTION_DETECTOR = 4039
+    WIFI_GAS_DETECTOR = 4040
     INOVA_ALARM_SYSTEM = 5e3
     INOVA_DETECTOR = 5001
     INOVA_SIREN = 5002
@@ -149,8 +170,10 @@ class NodeProtocol:
     BI_SECUR = 19
     HTTPWOLF = 20
     EXTERNAL_HOMEE = 21
-    HTTPMY_STROM = 24
     WMS = 23
+    HTTPMY_STROM = 24
+    HTTP_STECA = 25
+    MQTT_SHELLY = 27
     ALL = 100
 
 
@@ -169,6 +192,7 @@ class NodeState:
     BLOCKED = 11
     WAITING_FOR_WAKEUP = 12
     REMOTE_NODE_DELETED = 13
+    FIRMWARE_UPDATE_IN_PROGRESS = 14
 
 
 class AttributeType:
@@ -462,6 +486,68 @@ class AttributeType:
     SLAT_MIN_ANGLE = 322
     SLAT_MAX_ANGLE = 323
     MOTOR_ROTATION = 324
+    ENDPOSITION_CONFIGURATION = 325
+    AUTOMATIC_MODE_IMPULSE = 326
+    BRIEFLY_OPEN_IMPULSE = 327
+    PERMANENTLY_OPEN_IMPULSE = 328
+    WIND_THRESHOLD = 329
+    MOTOR_BLOCKED_ALARM = 330
+    FREEZE_PROTECTION = 331
+    FLYSCREEN = 332
+    SUN_PROTECTION = 333
+    MEMO = 334
+    SLAT_ROTATION_IMPULSE = 337
+    WIND_MONITORING_STATE = 338
+    HVAC_OPERATING_STATE = 339
+    EXTERNAL_TEMPERATURE_OFFSET = 340
+    FLOOR_TEMPERATURE_OFFSET = 341
+    DISPLAY_BRIGHTNESS_ACTIVE = 342
+    DISPLAY_BRIGHTNESS_DIMMED = 343
+    BUTTON_BRIGHTNESS_ACTIVE = 344
+    BUTTON_BRIGHTNESS_DIMMED = 345
+    DISPLAY_TEMPERATURE_SELECTION = 346
+    RESET_METER = 347
+    AUTOMATIC_RUNTIME_CALCULATION = 348
+    DOWN_POSITION = 349
+    DOWN_SLAT_POSITION = 350
+    FIRMWARE_UPDATEABLE = 351
+    COVALUE = 354
+    TARGET_TEMPERATURE_TYPE = 355
+    SETBACK_MODE = 356
+    SYSTEM_ALARM = 357
+    HEALTH_ALARM = 358
+    ACCESSCONTROL_ALARM = 359
+    SECURITY_ALARM = 360
+    EMERGENCY_ALARM = 361
+    CLOCK_ALARM = 362
+    APPLIANCE_ALARM = 363
+    WATERVALVE_ALARM = 364
+    WEATHER_ALARM = 365
+    IRRIGATION_ALARM = 366
+    GAS_ALARM = 367
+    PEST_ALARM = 368
+    LIGHT_ALARM = 369
+    WATERQUALITY_ALARM = 370
+    ANTI_THEFT_RESTRICTED = 371
+    UNKNOWN_METERING_VALUE = 372
+    COLOR_EXPERT = 373
+    SWITCH_MULTILEVEL_EXPERT = 375
+    UNKNOWN_SENSOR_VALUE = 376
+    DOOR_LOCK_EXPERT = 377
+    VOC_LEVEL = 352
+    VOC_VALUE = 353
+    VENTILATE_IMPULSE = 378
+    VIBRATION_ON_OFF = 379
+    SOUND_ON_OFF = 380
+    VIRTUAL_VOLANT_POSTION = 381
+    FABRIC_UNTENSIONING = 382
+    AUTOMATIC_REVERSING = 383
+    LOCKED = 384
+    WATCHDOG_ON_OFF = 385
+    IP_ADDRESS = 386
+    GAS_ALARM_STATE = 387
+    GAS_CONCENTRATION = 388
+    HOST_NAME = 389
 
 
 class AttributeState:
@@ -473,6 +559,7 @@ class AttributeState:
     INACTIVE = 5
     IGNORED = 6
     UNAVAILABLE = 7
+    STATE_UNLISTED = 9
 
 
 class AttributeChangedBy:
@@ -487,6 +574,7 @@ class AttributeBasedOn:
     EVENTS = 1
     INTERVAL = 2
     POLLING = 4
+    MANUAL = 8
 
 
 class HomeegramState:
@@ -532,6 +620,7 @@ class ErrorCode:
     CUBE_HEAL_PROGRESS = 131
     CUBE_SERVER_STARTED = 144
     NO_NODES_TO_ADD = 145
+    CUBE_SMART_START_INITIALIZING = 146
     NODE_BAD_LINK_QUALITY = 200
     NODE_IS_MISSING = 201
     NODE_WATER_DETECTED = 202
@@ -559,6 +648,7 @@ class ErrorCode:
     SETTING_NETWORK_UNINITIALIZED = 304
     SETTING_NETWORK_INITIALIZING = 305
     SETTING_NETWORK_INITIALIZED = 306
+    SETTING_GENERATING_CERTIFICATE = 307
     UPDATE_AVAILABLE = 400
     UPDATE_DOWNLOADING = 401
     UPDATE_INSTALLING = 402
@@ -611,6 +701,25 @@ class ErrorCode:
     QUAR_ZENABLE_SUCCESS = 811
     HOMEEGRAM_COULD_NOT_DOWNLOAD_TTS = 900
     HOMEEGRAM_TEST_RESULTS = 901
+    EMAIL_VERIFICATION_SUCCESS = 1100
+    EMAIL_VERIFICATION_CODE_EXPIRED = 1101
+    EMAIL_VERIFICATION_WRONG_CODE = 1102
+    EMAIL_VERIFICATION_NEEDED = 1103
+    EMAIL_VERIFICATION_ALREADY_VERIFIED = 1104
+    EMAIL_VERIFICATION_MAIL_SENT = 1105
+    PLAN_COPY_NOT_ALLOWED = 1200
+    PLAN_NODE_ALREADY_IN_OTHER_PLAN = 1201
+    PLAN_DELETE_FAILED = 1202
+    PLAN_REMOVE_NODE_FAILED = 1203
+    PLAN_ADD_NODE_FAILED = 1204
+    FIRMWARE_UPDATE_STARTED = 1300
+    FIRMWARE_UPDATE_UPLOADING = 1301
+    FIRMWARE_UPDATE_FILE_UPLOAD_COMPLETE = 1302
+    FIRMWARE_UPDATE_FAILED = 1303
+    FIRMWARE_UPDATE_SUCCESSFUL = 1304
+    FIRMWARE_UPDATE_WAITING_FOR_ACTIVATION = 1305
+    FIRMWARE_UPDATE_DEVICE_RESTARTED = 1306
+    UNLOCK_FAILED = 1400
 
 
 class ErrorCode:
